Bug#496027: Stopmotion patch

2010-12-06 Thread John S. Skogtvedt
Hello,

Klaus asked me to have a look at this for him. I've attached a patch
which replaces the kill `ps ax | grep command | ... cut` commands with
simply kill $(pidof command). Untested.

John.
diff -ur 
stopmotion-0.6.2.orig//src/presentation/frontends/qtfrontend/qtfrontend.cpp 
stopmotion-0.6.2/src/presentation/frontends/qtfrontend/qtfrontend.cpp
--- stopmotion-0.6.2.orig//src/presentation/frontends/qtfrontend/qtfrontend.cpp 
2010-12-06 09:44:51.0 +0100
+++ stopmotion-0.6.2/src/presentation/frontends/qtfrontend/qtfrontend.cpp   
2010-12-06 09:58:34.0 +0100
@@ -236,7 +236,7 @@
prefs-setPreference(importstartdeamon1, 
vgrabbj -f $IMAGEFILE -d $VIDEODEVICE -b -D 0 -i vga 
-L250);
prefs-setPreference(importstopdeamon1, 
-   kill -9 `ps ax | grep vgrabbj | grep -v grep | cut -b 
0-5`);
+   kill $(pidof vgrabbj));

// Default import option 3
prefs-setPreference(importname2, 
tr(dvgrab).toLatin1().constData());
@@ -246,7 +246,7 @@
dvgrab --format jpeg --jpeg-overwrite 
--jpeg-deinterlace --jpeg-width 640  
--jpeg-height 480 --frames 25 $IMAGEFILE);
prefs-setPreference(importstopdeamon2, 
-   kill -9 `ps ax | grep dvgrab | grep -v grep | cut -b 
0-5`);
+   kill $(pidof dvgrab));

// Default import option 4
prefs-setPreference(importname3, tr(videodog 
singleshot).toLatin1().constData());
@@ -264,7 +264,7 @@
dvgrab --format jpeg --jpeg-overwrite 
--jpeg-deinterlace --jpeg-width 640 
--jpeg-height 480 --every 25 $IMAGEFILE );
prefs-setPreference(importstopdeamon4, 
-   kill -9 `ps ax | grep dvgrab | grep -v grep | cut -b 
0-5`);
+   kill $(pidof dvgrab));
// 
---
 
// Default export options 



Bug#566543: Info received (Bug#566543: Acknowledgement (ath5k: regression: unable to connect to AP on channel 13))

2010-01-26 Thread John S. Skogtvedt
I reported this to the linux-wireless list, thread available
here:
http://news.gmane.org/find-root.php?message_id=%3c4B5CB7AB.7010105%40bzz.no%3e

One of the replies suggested installing CRDA (RFP #536502), which fixed
the problem.

According to Luis R. Rodriguez:
No, Atheros cards by default abide by a custom strict world regulatory
domain if CRDA is not present.




-- 
To UNSUBSCRIBE, email to debian-bugs-dist-requ...@lists.debian.org
with a subject of unsubscribe. Trouble? Contact listmas...@lists.debian.org



Bug#566543: ath5k: regression: unable to connect to AP on channel 13

2010-01-23 Thread John S. Skogtvedt
Package: linux-2.6
Version: 2.6.32-5
Severity: normal

With kernels 2.6.26 and 2.6.30 I am able to connect to an AP on channel 13 
without problems, with the following /etc/modprobe.d/cfg80211_reg.conf :
  options cfg80211 ieee80211_regdom=EU

On linux-image-2.6.32-trunk-686 I am not able to connect, nor does the AP show 
up when running iwlist scan.
I have tried both with and without the ieee80211_regdom option, as well as 
ieee80211_regdom=NO. cfg80211 autodetects regulatory domain DK if nothing is 
specified.

My configuration is as follows:
auto wlan0
iface wlan0 inet static
  wpa-driver wext
  wpa-ssid pingvin
  wpa-psk mykey
  address 192.168.1.10
  netmask 255.255.255.0
  gateway 192.168.1.1
  dns-nameservers ...
  dns-search ...

dmesg output with ieee80211_regdom=NO:

$ grep -e Linux version -e ath5k -e cfg80211 /var/log/dmesg.0
[0.00] Linux version 2.6.32-trunk-686 (Debian 2.6.32-5) 
(b...@decadent.org.uk) (gcc version 4.3.4 (Debian 4.3.4-6) ) #1 SMP Sun Jan 10 
06:32:16 UTC 2010
[8.197842] cfg80211: Using static regulatory domain info
[8.197846] cfg80211: Regulatory domain: US
[8.198141] cfg80211: Calling CRDA for country: US
[8.198190] cfg80211: Calling CRDA for country: NO
[8.400510] ath5k :01:0a.0: PCI INT A - Link[APC1] - GSI 16 (level, 
high) - IRQ 16
[8.400602] ath5k :01:0a.0: registered as 'phy0'
[9.251795] ath5k phy0: Atheros AR2414 chip found (MAC: 0x79, PHY: 0x45)
[9.252114] cfg80211: Calling CRDA for country: DK
[   61.626958] ath5k phy0: noise floor calibration timeout (2462MHz)

Please let me know if you need any more information.


-- Package-specific info:
** Kernel log: boot messages should be attached

** Model information
not available

** PCI devices:
00:00.0 Host bridge [0600]: nVidia Corporation nForce2 IGP2 [10de:01e0] (rev c1)
Subsystem: ASUSTeK Computer Inc. Device [1043:80ac]
Control: I/O- Mem+ BusMaster+ SpecCycle- MemWINV- VGASnoop- ParErr- 
Stepping- SERR- FastB2B- DisINTx-
Status: Cap+ 66MHz+ UDF- FastB2B+ ParErr- DEVSEL=fast TAbort- TAbort- 
MAbort- SERR- PERR- INTx-
Latency: 0
Region 0: Memory at e000 (32-bit, prefetchable) [size=32M]
Capabilities: access denied
Kernel driver in use: agpgart-nvidia

00:00.1 RAM memory [0500]: nVidia Corporation nForce2 Memory Controller 0 
[10de:01ea] (rev c1)
Subsystem: ASUSTeK Computer Inc. Device [1043:80ac]
Control: I/O- Mem- BusMaster- SpecCycle- MemWINV- VGASnoop- ParErr- 
Stepping- SERR- FastB2B- DisINTx-
Status: Cap- 66MHz+ UDF- FastB2B- ParErr- DEVSEL=fast TAbort- TAbort- 
MAbort- SERR- PERR- INTx-

00:00.2 RAM memory [0500]: nVidia Corporation nForce2 Memory Controller 4 
[10de:01ee] (rev c1)
Subsystem: ASUSTeK Computer Inc. Device [1043:80ac]
Control: I/O- Mem- BusMaster- SpecCycle- MemWINV- VGASnoop- ParErr- 
Stepping- SERR- FastB2B- DisINTx-
Status: Cap- 66MHz+ UDF- FastB2B- ParErr- DEVSEL=fast TAbort- TAbort- 
MAbort- SERR- PERR- INTx-

00:00.3 RAM memory [0500]: nVidia Corporation nForce2 Memory Controller 3 
[10de:01ed] (rev c1)
Subsystem: ASUSTeK Computer Inc. Device [1043:80ac]
Control: I/O- Mem- BusMaster- SpecCycle- MemWINV- VGASnoop- ParErr- 
Stepping- SERR- FastB2B- DisINTx-
Status: Cap- 66MHz+ UDF- FastB2B- ParErr- DEVSEL=fast TAbort- TAbort- 
MAbort- SERR- PERR- INTx-

00:00.4 RAM memory [0500]: nVidia Corporation nForce2 Memory Controller 2 
[10de:01ec] (rev c1)
Subsystem: ASUSTeK Computer Inc. Device [1043:80ac]
Control: I/O- Mem- BusMaster- SpecCycle- MemWINV- VGASnoop- ParErr- 
Stepping- SERR- FastB2B- DisINTx-
Status: Cap- 66MHz+ UDF- FastB2B- ParErr- DEVSEL=fast TAbort- TAbort- 
MAbort- SERR- PERR- INTx-

00:00.5 RAM memory [0500]: nVidia Corporation nForce2 Memory Controller 5 
[10de:01ef] (rev c1)
Subsystem: ASUSTeK Computer Inc. Device [1043:80ac]
Control: I/O- Mem- BusMaster- SpecCycle- MemWINV- VGASnoop- ParErr- 
Stepping- SERR- FastB2B- DisINTx-
Status: Cap- 66MHz+ UDF- FastB2B- ParErr- DEVSEL=fast TAbort- TAbort- 
MAbort- SERR- PERR- INTx-

00:01.0 ISA bridge [0601]: nVidia Corporation nForce2 ISA Bridge [10de:0060] 
(rev a4)
Subsystem: ASUSTeK Computer Inc. A7N8X Mainboard [1043:80ad]
Control: I/O+ Mem+ BusMaster+ SpecCycle+ MemWINV- VGASnoop- ParErr- 
Stepping- SERR- FastB2B- DisINTx-
Status: Cap+ 66MHz+ UDF- FastB2B+ ParErr- DEVSEL=fast TAbort- TAbort- 
MAbort- SERR- PERR- INTx-
Latency: 0
Capabilities: access denied

00:01.1 SMBus [0c05]: nVidia Corporation nForce2 SMBus (MCP) [10de:0064] (rev 
a2)
Subsystem: ASUSTeK Computer Inc. Device [1043:0c11]
Control: I/O+ Mem- BusMaster- SpecCycle- MemWINV- VGASnoop- ParErr- 
Stepping- SERR- FastB2B- DisINTx-
Status: Cap+ 66MHz+ UDF- FastB2B+ ParErr- DEVSEL=fast TAbort- TAbort- 
MAbort- SERR- PERR- INTx-
Interrupt: pin A routed to IRQ 12
Region 0: 

Bug#566543: Acknowledgement (ath5k: regression: unable to connect to AP on channel 13)

2010-01-23 Thread John S. Skogtvedt
Further information:

This also occurs on 2.6.30 using ath5k from compat-wireless-2010-01-23.



-- 
To UNSUBSCRIBE, email to debian-bugs-dist-requ...@lists.debian.org
with a subject of unsubscribe. Trouble? Contact listmas...@lists.debian.org



Bug#565450: python-twisted-conch: missing dependency: python-pyasn1

2010-01-15 Thread John S. Skogtvedt
Package: python-twisted-conch
Version: 1:9.0.0-1
Severity: normal

I got the following traceback attempting to use a Python program using 
python-twisted-conch:

  File /usr/lib/python2.5/site-packages/twisted/conch/ssh/transport.py, line 
30, in module 
from twisted.conch.ssh import keys  
   
  File /usr/lib/python2.5/site-packages/twisted/conch/ssh/keys.py, line 20, 
in module  
from pyasn1.type import univ
   
exceptions.ImportError: No module named pyasn1.type 

Installing the python-pyasn1 package fixed it.


-- System Information:
Debian Release: squeeze/sid
  APT prefers testing
  APT policy: (900, 'testing'), (800, 'unstable')
Architecture: i386 (i686)

Kernel: Linux 2.6.30-2-686 (SMP w/1 CPU core)
Locale: LANG=nb_NO.UTF-8, LC_CTYPE=nb_NO.UTF-8 (charmap=UTF-8)
Shell: /bin/sh linked to /bin/bash

Versions of packages python-twisted-conch depends on:
ii  python 2.5.4-5   An interactive high-level object-o
ii  python-central 0.6.14+nmu2   register and build utility for Pyt
ii  python-crypto  2.0.1+dfsg1-4 cryptographic algorithms and proto
ii  python-twisted-core9.0.0-1   Event-based framework for internet

python-twisted-conch recommends no packages.

python-twisted-conch suggests no packages.

-- no debconf information



-- 
To UNSUBSCRIBE, email to debian-bugs-dist-requ...@lists.debian.org
with a subject of unsubscribe. Trouble? Contact listmas...@lists.debian.org



Bug#550989: ltsp-client-core: getltscfg (lts.conf) should support wildcards

2009-10-14 Thread John S. Skogtvedt
Package: ltsp-client-core
Version: 5.1.90-1
Severity: wishlist
Tags: patch

It would be useful if getltscfg would support wildcards, e.g.:
[00:0C:6E:*]
XSERVER = nvidia

This is very useful in order to have specific settings for a subset of
computers. E.g. when buying a large number of computers of the same
model, they will usually have one or two MAC address series which can be
matched. The alternative is to add a separate section for each
computer, which requires a lot of work.

I have attached a patch which implements this, but while it seems to
work I can't guarantee that it's 100% correct.

-- System Information:
Debian Release: squeeze/sid
  APT prefers testing
  APT policy: (900, 'testing'), (800, 'unstable')
Architecture: i386 (i686)

Kernel: Linux 2.6.26-2-686 (SMP w/1 CPU core)
Locale: LANG=nb_NO.UTF-8, LC_CTYPE=nb_NO.UTF-8 (charmap=UTF-8)
Shell: /bin/sh linked to /bin/bash
-- 
To UNSUBSCRIBE, email to [EMAIL PROTECTED]
with a subject of unsubscribe. Trouble? Contact [EMAIL PROTECTED]



Bug#482553: ldm: password change doesn't work

2008-05-23 Thread John S. Skogtvedt
Package: ldm
Version: 2:2.0.3-1~40.etch.0
Severity: normal


When trying to log in as a user with an expired password,
I experienced the following problems:

1) ldm first prompted for new password, and then prompted again (to confirm).
  After that it got stuck - I could enter text, but nothing happened.
2) ldm doesn't check if the new password is equal to the old password.
  If it is, then the password won't be succesfully changed.
3) (with 1 and 2 fixed) ldm incorrectly zeros the password,
  so that the user has to enter the new password again to log in after
  a password change.

I have attached a patch which should fix these problems.

Steps to reproduce:
1) Expire a users password on the server.
2) Attempt to log in as the user with ldm.


-- System Information:
Debian Release: 4.0
  APT prefers stable
  APT policy: (500, 'stable')
Architecture: i386 (i686)
Shell:  /bin/sh linked to /bin/bash
Kernel: Linux 2.6.18-6-486
Locale: LANG=nb_NO.UTF-8, LC_CTYPE=nb_NO.UTF-8 (charmap=UTF-8)

Versions of packages ldm depends on:
ii  gtk2-engines [gtk2-eng 1:2.8.2-1 theme engines for GTK+ 2.x
ii  gtk2-engines-clearlook 1:2.8.2-1 Clearlooks GTK+ 2.x engine and the
ii  libatk1.0-01.12.4-3  The ATK accessibility toolkit
ii  libc6  2.3.6.ds1-13etch5 GNU C Library: Shared libraries
ii  libcairo2  1.2.4-4.1+etch1   The Cairo 2D vector graphics libra
ii  libfontconfig1 2.4.2-1.2 generic font configuration library
ii  libglib2.0-0   2.12.4-2  The GLib library of C routines
ii  libgtk2.0-02.8.20-7  The GTK+ graphical user interface 
ii  libpango1.0-0  1.14.8-5  Layout and rendering of internatio
ii  libx11-6   2:1.0.3-7 X11 client-side library
ii  libxcursor11.1.7-4   X cursor management library
ii  libxext6   1:1.0.1-2 X11 miscellaneous extension librar
ii  libxfixes3 1:4.0.1-5 X11 miscellaneous 'fixes' extensio
ii  libxi6 1:1.0.1-4 X11 Input extension library
ii  libxinerama1   1:1.0.1-4.1   X11 Xinerama extension library
ii  libxrandr2 2:1.1.0.2-5   X11 RandR extension library
ii  libxrender11:0.9.1-3 X Rendering Extension client libra
ii  openssh-client 1:4.3p2-9etch2Secure shell client, an rlogin/rsh
ii  xserver-xorg   1:7.1.0-19the X.Org X server
ii  xserver-xorg-core [xse 2:1.1.1-21etch4   X.Org X server -- core server

Versions of packages ldm recommends:
ii  netcat1.10-32TCP/IP swiss army knife

-- no debconf information
--- src.orig/sshutils.c	2008-05-23 14:36:04.0 +0200
+++ src/sshutils.c	2008-05-23 14:37:00.0 +0200
@@ -227,6 +227,10 @@
 
 while (TRUE) {
 get_passwd();
+if (!strcmp(oldpw, ldminfo.password)) {
+set_message(_(You have to enter a new password.));
+continue;
+}
 newpw1 = strdup(ldminfo.password);
 set_message(_(Please enter your password again to verify.));
 get_passwd();
@@ -240,6 +244,7 @@
 }
 
 /* send old password first */
+seen = expect(fd, 30.0, ssword:, NULL);
 write(fd, oldpw, strlen(oldpw));
 write(fd, \n, 1);
 
@@ -256,7 +261,6 @@
 
 seen = expect(fd, 30.0, updated successfully, NULL);
 if (seen == 1) {
-bzero(ldminfo.password, sizeof ldminfo.password);
 return 2;
 }
--- getltscfg.c.orig	2009-09-18 14:16:49.0 +0200
+++ getltscfg.c	2009-10-13 12:24:56.0 +0200
@@ -28,6 +28,8 @@
 #include  net/if.h
 #include  netinet/in.h
 #include  arpa/inet.h
+#define _GNU_SOURCE /* need the fnmatch FNM_CASEFOLD flag */
+#include  fnmatch.h
 #include  getltscfg.h
 
 extern FILE *yyin;
@@ -191,13 +193,17 @@
 //
 // find_chain_entry(), returns TRUE if it found the entry, and FALSE otherwise
 //
-int find_chain_entry(char *name)
+int find_chain_entry(char *name, int glob)
 {
 int	fFound = FALSE;
 SECTTYPE *worksect;
 cursect = headsect;
+int matches = FALSE;
 while( cursect  !fFound ){
-if(strcasecmp(cursect-name,name) == 0){
+matches = strcasecmp(cursect-name,name) == 0;
+if (glob)
+matches = !matches  fnmatch(cursect-name, name, FNM_CASEFOLD) == 0;
+if(matches){
 CHAINTYPE *chainptr = (CHAINTYPE *)malloc(sizeof(CHAINTYPE));
 worksect = cursect;
 fFound = TRUE;
@@ -429,8 +435,8 @@
 // that we are interested in.  Then, walk through the linked list
 // looking for any entries that indicate we want to inherit entries
 // from another section.  We'll build a new linked list of those
 // sections that we want to inherit from. Then, we'll tack the 'Default'
 // section on the end of that.  Once we have the inheritance list, we
 // need to walk that list backwards, building the list of
 // tuples (keyword/value pairs).
 // Finally, when we are all done, we should have all of the values that
@@ -447,7 +453,7 @@
 i = 0;
 fFound = FALSE;
 while( aWorkstationId[i]  !fFound ){
-if(find_chain_entry(aWorkstationId[i])){
+if(find_chain_entry(aWorkstationId[i], FALSE)){
 	fFound = TRUE;
 }
 i++;
@@ -458,17 +464,33 @@
 curtuple = chain-sect-tuple_list;
 while(curtuple){
 if(strcasecmp(curtuple-keyword,LIKE) == 0)
-status = find_chain_entry(curtuple-value);
+status = find_chain_entry(curtuple-value, FALSE);
 
 curtuple = curtuple-next;
 }
 chain = chain-next;
 }
 
+for (i=0; aWorkstationId[i]; ++i){
+if((status = find_chain_entry(aWorkstationId[i], TRUE))){
+chain = headchain;
+while(chain){
+curtuple = chain-sect-tuple_list;
+while(curtuple){
+if(strcasecmp(curtuple-keyword,LIKE) == 0)
+status = find_chain_entry(curtuple-value, FALSE);
+
+curtuple = curtuple-next;
+}
+chain = chain-next;
+}
+}
+}
+
 //
 // the last entry in the chain is the '[Default]' entry
 //
-status = find_chain_entry(default);
+status = find_chain_entry(default, FALSE);
 
 
 curchain = tailchain;
@@ -429,8 +435,8 @@
 // looking for any entries that indicate we want to inherit entries
 // from another section.  We'll build a new linked list of those
-// sections that we want to inherit from. Then, we'll tack the 'Default'
-// section on the end of that.  Once we have the inheritance list, we
+// sections that we want to inherit from. Then, we'll tack any wildcard matches
+// and the 'Default' section on the end of that.  Once we have the inheritance list, we
 // need to walk that list backwards, building the list of
 // tuples (keyword/value pairs).


Bug#482553: ldm: password change doesn't work

2008-06-05 Thread John S. Skogtvedt
Vagrant Cascadian skrev:
 On Fri, May 23, 2008 at 03:59:18PM +0200, John S. Skogtvedt wrote:
 When trying to log in as a user with an expired password,
 I experienced the following problems:
 ...snip... 
 I have attached a patch which should fix these problems.
 
 applied your patch to the version just uploaded to unstable, even though
 there are still likely cases where it will hang. i didn't close the bug
 since there are outstanding issues.
 
 i am curious if this line is a good idea, though:
 
 @@ -256,7 +261,6 @@
 
  seen = expect(fd, 30.0, updated successfully, NULL);
  if (seen == 1) {
 -bzero(ldminfo.password, sizeof ldminfo.password);
  return 2;
  }
 
 by removing that line, is it leaving the password sitting in memory?
 
 live well,
   vagrant
 

Zeroing the password there means that the user has to enter the password
a third time to be able to log in (and ldm doesn't give proper feedback).

It shouldn't be a problem, because the password is zeroed in main().




